==> EspoCRM-9.3.0.zip: EspoCRM-9.3.0/application/Espo/Core/Upgrades/Migrations/V9_2/AfterUpgrade.php <==
<?php
/************************************************************************
 * This file is part of EspoCRM.
 *
 * EspoCRM – Open Source CRM application.
 * Copyright (C) 2014-2026 EspoCRM, Inc.
 * Website: https://www.espocrm.com
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 *
 * In accordance with Section 7(b) of the GNU Affero General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "EspoCRM" word.
 ************************************************************************/

namespace Espo\Core\Upgrades\Migrations\V9_2;

use Espo\Core\Upgrades\Migration\Script;
use Espo\Entities\Note;
use Espo\ORM\EntityManager;
use Espo\ORM\Query\UpdateBuilder;

class AfterUpgrade implements Script
{
    public function __construct(
        private EntityManager $entityManager,
    ) {}

    public function run(): void
    {
        $this->updateNotes();
    }

    private function updateNotes(): void
    {
        $update = UpdateBuilder::create()
            ->in(Note::ENTITY_TYPE)
            ->set([
                'type' => Note::TYPE_UPDATE,
            ])
            ->where(['type' => 'Status'])
            ->build();

        $this->entityManager->getQueryExecutor()->execute($update);
    }
}

==> EspoCRM-9.3.1.zip: EspoCRM-9.3.1/application/Espo/Core/Upgrades/Migrations/V8_1/AfterUpgrade.php <==
<?php
/************************************************************************
 * This file is part of EspoCRM.
 *
 * EspoCRM – Open Source CRM application.
 * Copyright (C) 2014-2026 EspoCRM, Inc.
 * Website: https://www.espocrm.com
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 *
 * In accordance with Section 7(b) of the GNU Affero General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "EspoCRM" word.
 ************************************************************************/

namespace Espo\Core\Upgrades\Migrations\V8_1;

use Espo\Core\Container;
use Espo\Core\Upgrades\Migration\Script;
use Espo\Core\InjectableFactory;
use Espo\Core\Utils\Config;

class AfterUpgrade implements Script
{
    public function __construct(
        private Container $container
    ) {}

    public function run(): void
    {
        $config = $this->container->getByClass(Config::class);

        $configWriter = $this->container->getByClass(InjectableFactory::class)
            ->create(Config\ConfigWriter::class);

        $configWriter->setMultiple([
            'phoneNumberNumericSearch' => false,
            'phoneNumberInternational' => false,
        ]);

        if ($config->get('pdfEngine') === 'Tcpdf') {
            $configWriter->set('pdfEngine', 'Dompdf');
        }

        $configWriter->save();
    }
}
